import type { Redis, Cluster } from 'ioredis';
declare global {
    var __wzfConfig: WzfConfig;
    var __reWzfConfig: Function;
}
type ENV_WZF = {
    [key: string]: string | boolean | number;
};
export type UserConfig = {
    $wzf?: {
        rds_host: string;
        rds_pwd: string;
        rds_type?: 'single' | 'cluster' | 'Sentinel';
        rds_name?: string;
        rds_db?: number;
    };
    mode?: 'spa' | 'ssr';
    stmode?: 'dev' | 'prod' | 'smm' | 'xn';
    encryption?: boolean;
    env?: ENV_WZF;
    server?: {
        https?: boolean;
        domain?: string;
        timeout?: number;
        open?: boolean;
        csp?: {
            /**
             * @default true
            */
            enabled: boolean;
            /**
             * csp配置项，按需修改单项
             * @default {
             *  'default-src': ["'self'"],
             *  'base-uri': ["'self'"],
             *  'font-src': ["'self'", 'https:', 'data:'],
             *  'form-action': ["'self'"],
             *  'frame-ancestors': ["'self'"],
             *  'img-src': ["'self'", 'data:'],
             *  'object-src': ["'none'"],
             *  // 'script-src': ["'self'", "'unsafe-inline'","'unsafe-eval'"],
             *  'script-src': ["'self'"],
             *  'script-src-attr': ["'none'"],
             *  'style-src': ["'self'", 'https:', "'unsafe-inline'"],
             *  'connect-src': ["'self'"],
             *  'frame-src': ["'self'"],
             *  }
             * @example {
             *  'frame-src': ["'self'", "*.jinhudao.com"],
             *  "img-src": ["'self'", '*.baidu.com']
             * }
           */
            directives?: {
                'default-src'?: string[];
                'base-uri'?: string[];
                'font-src'?: string[];
                'form-action'?: string[];
                'frame-ancestors'?: string[];
                'img-src'?: string[];
                'object-src'?: string[];
                'script-src'?: string[];
                'script-src-attr'?: string[];
                'style-src'?: string[];
                'connect-src'?: string[];
                'frame-src'?: string[];
            };
        };
    };
    proxy?: any;
    apps: {
        [key: string]: {
            port: number;
            hidePort?: boolean;
            host?: string;
            enabled?: boolean;
        };
    };
};
export type WzfConfig = {
    appsPath: string;
    wzfPath: string;
    rdsClient?: Redis | Cluster;
    cliMode: 'dev' | 'build' | 'start';
} & UserConfig;
declare const _getWzfConfig: (cliMode: 'dev' | 'build' | 'start') => Promise<WzfConfig>;
export default _getWzfConfig;
